==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/ui/src/app/assets/components/asset-details/edit-asset/asset-details-panel/asset-details-links/asset-link-section/asset-link-item/asset-link-item.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Component, EventEmitter, Input, Output } from '@angular/core';
import {
    AssetLink,
    AssetLinkType,
} from '../../../../../../../../../../projects/streampipes/platform-services/src/public-api';
import { Router } from '@angular/router';

@Component({
    selector: 'sp-asset-link-item',
    templateUrl: './asset-link-item.component.html',
    styleUrls: ['./asset-link-item.component.scss'],
})
export class SpAssetLinkItemComponent {
    @Input()
    assetLink: AssetLink;

    @Input()
    assetLinkType: AssetLinkType;

    @Input()
    editMode: boolean;

    @Output()
    openEditAssetLinkEmitter: EventEmitter<AssetLink> =
        new EventEmitter<AssetLink>();

    @Output()
    deleteAssetLinkEmitter: EventEmitter<AssetLink> =
        new EventEmitter<AssetLink>();

    constructor(private router: Router) {}

    openLink(): void {
        this.router.navigate([
            ...this.assetLinkType.navPaths,
            this.assetLink.resourceId,
        ]);
    }

    editLink(): void {
        this.openEditAssetLinkEmitter.emit(this.assetLink);
    }

    deleteLink(): void {
        this.deleteAssetLinkEmitter.emit(this.assetLink);
    }
}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/ui/src/app/assets/components/asset-details/edit-asset/asset-details-panel/asset-details-links/asset-link-section/asset-link-item/asset-link-item.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Component, EventEmitter, Input, Output } from '@angular/core';
import { AssetLink, AssetLinkType } from '@streampipes/platform-services';
import { Router } from '@angular/router';

@Component({
    selector: 'sp-asset-link-item',
    templateUrl: './asset-link-item.component.html',
    styleUrls: ['./asset-link-item.component.scss'],
    standalone: false,
})
export class SpAssetLinkItemComponent {
    @Input()
    assetLink: AssetLink;

    @Input()
    assetLinkType: AssetLinkType;

    @Input()
    editMode: boolean;

    @Output()
    openEditAssetLinkEmitter: EventEmitter<AssetLink> =
        new EventEmitter<AssetLink>();

    @Output()
    deleteAssetLinkEmitter: EventEmitter<AssetLink> =
        new EventEmitter<AssetLink>();

    constructor(private router: Router) {}

    openLink(): void {
        this.router.navigate([
            ...this.assetLinkType.navPaths,
            this.assetLink.resourceId,
        ]);
    }

    editLink(): void {
        this.openEditAssetLinkEmitter.emit(this.assetLink);
    }

    deleteLink(): void {
        this.deleteAssetLinkEmitter.emit(this.assetLink);
    }
}
